<template>
	<div class="echarts-wrapper" @click="toParentPage">
		<div class="echarts-content" ref="chart"></div>
	</div>
</template>

<script>
import * as echarts from 'echarts';
import {
	endurance
} from '@/assets/js/api'
export default {
	name: "RoseChartED",
	chart: "",
	chartData: [],
	props: {
		id: {
			type: String,
			default: ""
		}
	},
	data() {
		return {}
	},
	methods: {
		toParentPage() {
			window.parent.parent.postMessage({
				cmd: "syncPage",
				params: {
					pageInfo: {
						label: "电池续航能力历史查询",
						name: "endure",
						src: "#/reportStatistics/endure",
						closable: true
					},
				}
			}, "*");
		},
		setOption(opt) {
			this.$options.chart.setOption(opt);
		},
		organizeData(data) {
			let option = {
				tooltip: {
					trigger: 'item'
				},
				series: [{
					type: 'pie',
					center: ['50%', '50%'],
					radius: ['0', '50%'],
					itemStyle: {
						color(params) {
							return data[params.dataIndex].color;
						},
					},
					data: data
				}]
			};

			// 设置图表配置项
			this.setOption(option);
		},
		setData(sendData) {
			if (sendData) {
				this.$options.chartData = sendData;
				this.organizeData(sendData)
			} else {
				this.postData()
				setInterval(() => {
					this.postData()
				}, 3000)
			}
		},
		postData() {
			let userId = localStorage.getItem('userId');
			let params = {
				userId: userId
			}
			endurance(params).then((res) => {
				if (res.data.code == 1) {
					let optionData = [{
						value: 0,
						name: '续航1小时内',
						color: '#E85D22'
					},
					{
						value: 0,
						name: '续航1小时到2小时',
						color: '#76CFDD'
					},
					{
						value: 0,
						name: '续航2小时到3小时',
						color: '#FEDB5B'
					},
					{
						value: 0,
						name: '续航3小时以上',
						color: '#8278E9'
					},
					]
					let resData = res.data.data;
					for (let key in resData) {
						optionData.map(item => {
							if (item.name == key) {
								item.value = resData[key]
							}
						})
					}
					this.$options.chartData = optionData;
					this.organizeData(optionData)
				}
			}).catch((err) => {
				console.log(err)
			});
		},
		resize() {
			setTimeout(() => {
				this.$options.chart.resize();
				if (JSON.stringify(this.$options.chartData) != '{}') {
					this.setData(this.$options.chartData);
				}
			}, 300)
		}
	},
	mounted() {
		// 基于准备好的dom，初始化echarts实例
		this.$options.chart = echarts.init(this.$refs.chart);

		window.addEventListener('resize', this.resize);
	},
	destroyed() {
		window.removeEventListener('resize', this.resize);
	}
}
</script>

<style scoped>
</style>